@@ -13,17 +13,14 @@ SequenceAnalysis.GetProteinOrganism = function(UniprotKB)
     stop("Please Enter the uniprot id of your desired protein")
   else
   {
-    Result=NULL
-    url = paste("http://www.uniprot.org/uniprot/",UniprotKB,sep = "")
-    mydata=tryCatch(readLines(url,n=5),error=function(err){print("Connection Error"); return(NULL)})
+    url = paste(Protein_Address,UniprotKB,sep = "")
+    mydata=tryCatch(readLines(url,n=5,warn=FALSE),error=function(err){print("Connection Error"); return(NULL)})
     if (!is.null(mydata))
     {
       Line=ifelse(length(grep("protein",mydata))>0,grep("protein",mydata),2)
       mydata = gsub(".*<title>(.*)</title>.*","\\1", mydata[Line])
       mydata=unlist(strsplit(mydata," - "))
-      Organism=grep("\\(",mydata)
-      if(length(Organism)==0)
-        Organism=3
+      Organism=ifelse(length(mydata)>3,3,length(mydata))
       Result=c(Protein = mydata[Organism-1],Gene = ifelse(Organism>2,mydata[Organism-2],"N/A"),Organism=mydata[Organism])
     }
     return(Result)
